.. sphinx-mcp documentation master file, created by
   sphinx-quickstart on Sat Jul  5 21:22:54 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Example MCP server: ``everything``
==================================

``everything`` is a Model Context Protocol (MCP) server that
   *attempts to exercise all the features of the MCP protocol.
   It is not intended to be a useful server, but rather a test server for builders of MCP clients.
   It implements prompts, tools, resources, sampling, and more to showcase MCP capabilities.*

   Source: `everything`_ as part of the official MCP examples on GitHub.


.. toctree::
   :maxdepth: 4
   :caption: MCP artefacts

   tools
   prompts
   resources
   resource_templates

.. _everything: https://github.com/modelcontextprotocol/servers/tree/main/src/everything
